summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--chart2/source/view/charttypes/Splines.cxx4
-rw-r--r--desktop/source/deployment/registry/executable/dp_executable.cxx2
-rw-r--r--editeng/source/editeng/editdoc.cxx2
-rw-r--r--editeng/source/editeng/impedit3.cxx4
-rw-r--r--editeng/source/outliner/outliner.cxx2
-rw-r--r--filter/source/xslt/odf2xhtml/export/common/table/table.xsl2
-rw-r--r--filter/source/xslt/odf2xhtml/export/common/table/table_columns.xsl2
-rw-r--r--forms/source/richtext/richtextimplcontrol.hxx2
-rw-r--r--jvmfwk/source/elements.hxx2
-rw-r--r--odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilterDetection/filterdetect.cxx2
-rw-r--r--sax/test/sax/testsax.cxx4
-rw-r--r--sd/source/filter/html/htmlex.cxx2
-rw-r--r--sd/source/ui/view/drviewsi.cxx2
-rw-r--r--starmath/source/dialog.cxx2
-rw-r--r--starmath/source/mathmlexport.cxx4
-rw-r--r--starmath/source/node.cxx2
-rw-r--r--starmath/source/parse.cxx2
-rw-r--r--svx/source/dialog/srchdlg.cxx2
-rw-r--r--sw/inc/crsrsh.hxx2
-rw-r--r--sw/inc/editsh.hxx4
-rw-r--r--sw/source/core/access/accportions.hxx2
-rw-r--r--sw/source/core/doc/docruby.cxx8
-rw-r--r--sw/source/core/layout/atrfrm.cxx2
-rw-r--r--sw/source/core/layout/colfrm.cxx2
-rw-r--r--sw/source/core/layout/ftnfrm.cxx2
-rw-r--r--sw/source/core/text/itrcrsr.cxx2
-rw-r--r--sw/source/core/text/pormulti.cxx6
-rw-r--r--sw/source/core/unocore/unoobj.cxx4
-rw-r--r--sw/source/filter/ww8/wrtw8nds.cxx2
-rw-r--r--sw/source/ui/index/swuiidxmrk.cxx2
-rw-r--r--xmloff/source/forms/elementexport.hxx2
31 files changed, 42 insertions, 42 deletions
diff --git a/chart2/source/view/charttypes/Splines.cxx b/chart2/source/view/charttypes/Splines.cxx
index b4f7b8d31057..9992f9defd04 100644
--- a/chart2/source/view/charttypes/Splines.cxx
+++ b/chart2/source/view/charttypes/Splines.cxx
@@ -676,9 +676,9 @@ void SplineCalculater::CalculateBSplines(
, sal_uInt32 nResolution
, sal_uInt32 nDegree )
{
- // nResolution is ODF1.2 file format attribut chart:spline-resolution and
+ // nResolution is ODF1.2 file format attribute chart:spline-resolution and
// ODF1.2 spec variable k. Causion, k is used as index in the spec in addition.
- // nDegree is ODF1.2 file format attribut chart:spline-order and
+ // nDegree is ODF1.2 file format attribute chart:spline-order and
// ODF1.2 spec variable p
OSL_ASSERT( nResolution > 1 );
OSL_ASSERT( nDegree >= 1 );
diff --git a/desktop/source/deployment/registry/executable/dp_executable.cxx b/desktop/source/deployment/registry/executable/dp_executable.cxx
index fd1931185ff4..5886eab9dfcf 100644
--- a/desktop/source/deployment/registry/executable/dp_executable.cxx
+++ b/desktop/source/deployment/registry/executable/dp_executable.cxx
@@ -236,7 +236,7 @@ void BackendImpl::ExecutablePackageImpl::processPackage_(
return;
}
sal_uInt64 attributes = 0;
- //Setting the executable attribut does not affect executables on Windows
+ //Setting the executable attribute does not affect executables on Windows
if (getFileAttributes(attributes))
{
if(getMyBackend()->m_context == "user")
diff --git a/editeng/source/editeng/editdoc.cxx b/editeng/source/editeng/editdoc.cxx
index 356975c5c66c..fc2d35f019bb 100644
--- a/editeng/source/editeng/editdoc.cxx
+++ b/editeng/source/editeng/editdoc.cxx
@@ -1362,7 +1362,7 @@ void ContentNode::ExpandAttribs( sal_Int32 nIndex, sal_Int32 nNew, SfxItemPool&
bExpand = true;
if( bExpandedEmptyAtIndexNull )
{
- // Check if this kind of attribut was empty and expanded here...
+ // Check if this kind of attribute was empty and expanded here...
sal_uInt16 nW = pAttrib->GetItem()->Which();
for ( sal_uInt16 nA = 0; nA < nAttr; nA++ )
{
diff --git a/editeng/source/editeng/impedit3.cxx b/editeng/source/editeng/impedit3.cxx
index e3b33bf859be..51fe1fa203bc 100644
--- a/editeng/source/editeng/impedit3.cxx
+++ b/editeng/source/editeng/impedit3.cxx
@@ -4217,8 +4217,8 @@ sal_Int32 ImpEditEngine::GetSpaceBeforeAndMinLabelWidth(
const ContentNode *pNode,
sal_Int32 *pnSpaceBefore, sal_Int32 *pnMinLabelWidth ) const
{
- // nSpaceBefore matches the ODF attribut text:space-before
- // nMinLabelWidth matches the ODF attribut text:min-label-width
+ // nSpaceBefore matches the ODF attribute text:space-before
+ // nMinLabelWidth matches the ODF attribute text:min-label-width
const SvxNumberFormat *pNumFmt = GetNumberFormat( pNode );
diff --git a/editeng/source/outliner/outliner.cxx b/editeng/source/outliner/outliner.cxx
index e019d91b33eb..69c3e753b8fb 100644
--- a/editeng/source/outliner/outliner.cxx
+++ b/editeng/source/outliner/outliner.cxx
@@ -1579,7 +1579,7 @@ Rectangle Outliner::ImpCalcBulletArea( sal_Int32 nPara, bool bAdjust, bool bRetu
bool bOutlineMode = ( pEditEngine->GetControlWord() & EE_CNTRL_OUTLINER ) != 0;
- // the ODF attribut text:space-before which holds the spacing to add to the left of the label
+ // the ODF attribute text:space-before which holds the spacing to add to the left of the label
const short nSpaceBefore = pFmt->GetAbsLSpace() + pFmt->GetFirstLineOffset();
const SvxLRSpaceItem& rLR = (const SvxLRSpaceItem&) pEditEngine->GetParaAttrib( nPara, bOutlineMode ? EE_PARA_OUTLLRSPACE : EE_PARA_LRSPACE );
diff --git a/filter/source/xslt/odf2xhtml/export/common/table/table.xsl b/filter/source/xslt/odf2xhtml/export/common/table/table.xsl
index a39367e676ec..249ab0469035 100644
--- a/filter/source/xslt/odf2xhtml/export/common/table/table.xsl
+++ b/filter/source/xslt/odf2xhtml/export/common/table/table.xsl
@@ -84,7 +84,7 @@
<xsl:variable name="allVisibleTableRows" select="table:table-row[not(@table:visibility = 'collapse' or @table:visibility = 'filter')][count(ancestor-or-self::table:table) = $tableLevel] |
table:table-header-rows/descendant::table:table-row[not(@table:visibility = 'collapse' or @table:visibility = 'filter')][count(ancestor-or-self::table:table) = $tableLevel] |
table:table-row-group/descendant::table:table-row[not(@table:visibility = 'collapse' or @table:visibility = 'filter')][count(ancestor-or-self::table:table) = $tableLevel]" />
- <!-- As the alignment of a table is by 'align' attribut is deprecated and as the CSS 'float' attribute not well displayed,
+ <!-- As the alignment of a table is by 'align' attribute is deprecated and as the CSS 'float' attribute not well displayed,
we do a trick by encapsulating the table with a aligned 'div' element-->
<xsl:variable name="table-alignment" select="key('styles', @style:name = current()/@table:style-name)/*/@table:align" />
<xsl:choose>
diff --git a/filter/source/xslt/odf2xhtml/export/common/table/table_columns.xsl b/filter/source/xslt/odf2xhtml/export/common/table/table_columns.xsl
index 852d9fd84598..352bf4f24710 100644
--- a/filter/source/xslt/odf2xhtml/export/common/table/table_columns.xsl
+++ b/filter/source/xslt/odf2xhtml/export/common/table/table_columns.xsl
@@ -195,7 +195,7 @@
<xsl:template name="table-debug-allTableColumns">
<xsl:param name="allTableColumns" />
- <!-- debug output as table summary attribut in html -->
+ <!-- debug output as table summary attribute in html -->
<xsl:attribute name="summary">
<xsl:call-template name="table-debug-column-out">
<xsl:with-param name="allTableColumns" select="$allTableColumns" />
diff --git a/forms/source/richtext/richtextimplcontrol.hxx b/forms/source/richtext/richtextimplcontrol.hxx
index 391ec18c169a..bd2126fcb009 100644
--- a/forms/source/richtext/richtextimplcontrol.hxx
+++ b/forms/source/richtext/richtextimplcontrol.hxx
@@ -150,7 +150,7 @@ namespace frm
long HandleCommand( const CommandEvent& _rEvent );
private:
- // updates the cache with the state provided by the given attribut handler
+ // updates the cache with the state provided by the given attribute handler
void implUpdateAttribute( AttributeHandlerPool::const_iterator _pHandler );
// updates the cache with the given state, and calls listeners (if necessary)
diff --git a/jvmfwk/source/elements.hxx b/jvmfwk/source/elements.hxx
index d3f0dfae1481..aaf22b0187b9 100644
--- a/jvmfwk/source/elements.hxx
+++ b/jvmfwk/source/elements.hxx
@@ -90,7 +90,7 @@ public:
an no further elements are read.
*/
void loadFromNode(xmlDoc * pDoc,xmlNode * pJavaInfo);
- /** The attribut nil will be set to false. The function gets the value
+ /** The attribute nil will be set to false. The function gets the value
javaSettings/updated from the javavendors.xml and writes it to
javaInfo@vendorUpdate in javasettings.xml
*/
diff --git a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilterDetection/filterdetect.cxx b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilterDetection/filterdetect.cxx
index ebe775324e0e..31de9dedb951 100644
--- a/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilterDetection/filterdetect.cxx
+++ b/odk/examples/DevelopersGuide/OfficeDev/FilterDevelopment/FlatXmlFilterDetection/filterdetect.cxx
@@ -114,7 +114,7 @@ OUString SAL_CALL FilterDetect::detect(Sequence< PropertyValue >& aArguments )
}
// flatxml starts with an office:document element. this element
- // conatains a clas="..." attribut by which we can deduct the
+ // conatains a clas="..." attribute by which we can deduct the
// type of document that is to be loaded
// WARNING:
diff --git a/sax/test/sax/testsax.cxx b/sax/test/sax/testsax.cxx
index bfcf4eefdc63..fda1614ab72d 100644
--- a/sax/test/sax/testsax.cxx
+++ b/sax/test/sax/testsax.cxx
@@ -472,7 +472,7 @@ void OSaxParserTest::testSimple( const Reference < XParser > &rParser )
{
rParser->parseStream( source );
ERROR_ASSERT( pDocHandler->m_iElementCount == 4 , "wrong element count" );
- ERROR_ASSERT( pDocHandler->m_iAttributeCount == 2 , "wrong attribut count" );
+ ERROR_ASSERT( pDocHandler->m_iAttributeCount == 2 , "wrong attribute count" );
ERROR_ASSERT( pDocHandler->m_iCharCount == 130 , "wrong char count" );
ERROR_ASSERT( pDocHandler->m_iWhitespaceCount == 0, "wrong whitespace count" );
}
@@ -537,7 +537,7 @@ void OSaxParserTest::testNamespaces( const Reference < XParser > &rParser )
{
rParser->parseStream( source );
ERROR_ASSERT( pDocHandler->m_iElementCount == 6 , "wrong element count" );
- ERROR_ASSERT( pDocHandler->m_iAttributeCount == 2 , "wrong attribut count" );
+ ERROR_ASSERT( pDocHandler->m_iAttributeCount == 2 , "wrong attribute count" );
ERROR_ASSERT( pDocHandler->m_iCharCount == 33, "wrong char count" );
ERROR_ASSERT( pDocHandler->m_iWhitespaceCount == 0 , "wrong whitespace count" );
}
diff --git a/sd/source/filter/html/htmlex.cxx b/sd/source/filter/html/htmlex.cxx
index a5923240f933..f6619fc68563 100644
--- a/sd/source/filter/html/htmlex.cxx
+++ b/sd/source/filter/html/htmlex.cxx
@@ -2710,7 +2710,7 @@ OUString HtmlExport::CreateImage( const OUString& aImage, const OUString& aAltTe
}
else
{
- // Agerskov: HTML 4.01 has to have an alt attribut even if it is an empty string
+ // Agerskov: HTML 4.01 has to have an alt attribute even if it is an empty string
aStr.append(" alt=\"\"");
}
diff --git a/sd/source/ui/view/drviewsi.cxx b/sd/source/ui/view/drviewsi.cxx
index 37ca292fe701..b66d2d2919ff 100644
--- a/sd/source/ui/view/drviewsi.cxx
+++ b/sd/source/ui/view/drviewsi.cxx
@@ -145,7 +145,7 @@ void DrawViewShell::AssignFrom3DWindow()
nSId, SFX_CALLMODE_SYNCHRON | SFX_CALLMODE_RECORD, &aItem, 0L );
// Determine if a FILL attribute is set.
- // If not, hard set a fill attribut
+ // If not, hard set a fill attribute
XFillStyle eFillStyle = ITEMVALUE( aSet, XATTR_FILLSTYLE, XFillStyleItem );
if(eFillStyle == XFILL_NONE)
aSet.Put(XFillStyleItem (XFILL_SOLID));
diff --git a/starmath/source/dialog.cxx b/starmath/source/dialog.cxx
index cc22063da05d..919aff84ae53 100644
--- a/starmath/source/dialog.cxx
+++ b/starmath/source/dialog.cxx
@@ -1875,7 +1875,7 @@ IMPL_LINK( SmSymDefineDialog, ChangeClickHdl, Button *, EMPTYARG pButton )
// get new Sybol to use
//! get font from symbol-disp lay since charset-display does not keep
- //! the bold attribut.
+ //! the bold attribute.
const SmSym aNewSymbol( pSymbols->GetText(), pCharsetDisplay->GetFont(),
pCharsetDisplay->GetSelectCharacter(), pSymbolSets->GetText() );
diff --git a/starmath/source/mathmlexport.cxx b/starmath/source/mathmlexport.cxx
index a24b3fc33b74..eabb6607bc07 100644
--- a/starmath/source/mathmlexport.cxx
+++ b/starmath/source/mathmlexport.cxx
@@ -1277,7 +1277,7 @@ static bool lcl_HasEffectOnMathvariant( const SmTokenType eType )
void SmXMLExport::ExportFont(const SmNode *pNode, int nLevel)
{
- // gather the mathvariant attribut relevant data from all
+ // gather the mathvariant attribute relevant data from all
// successively following SmFontNodes...
int nBold = -1; // for the following variables: -1 = yet undefined; 0 = false; 1 = true;
@@ -1480,7 +1480,7 @@ void SmXMLExport::ExportVerticalBrace(const SmNode *pNode, int nLevel)
{//Scoping
// using accents will draw the over-/underbraces too close to the base
// see http://www.w3.org/TR/MathML2/chapter3.html#id.3.4.5.2
- // also XML_ACCENT is illegal with XML_MUNDER. Thus no XML_ACCENT attribut here!
+ // also XML_ACCENT is illegal with XML_MUNDER. Thus no XML_ACCENT attribute here!
SvXMLElementExport aOver2(*this, XML_NAMESPACE_MATH,which, true, true);
ExportNodes(pNode->GetSubNode(0), nLevel);
AddAttribute(XML_NAMESPACE_MATH, XML_STRETCHY, XML_TRUE);
diff --git a/starmath/source/node.cxx b/starmath/source/node.cxx
index 4e0f561113ab..5b5baab9f462 100644
--- a/starmath/source/node.cxx
+++ b/starmath/source/node.cxx
@@ -2396,7 +2396,7 @@ void SmRectangleNode::Arrange(const OutputDevice &rDev, const SmFormat &/*rForma
nHeight += 2 * nTmpBorderWidth;
//! use this method in order to have 'SmRect::HasAlignInfo() == true'
- //! and thus having the attribut-fences updated in 'SmRect::ExtendBy'
+ //! and thus having the attribute-fences updated in 'SmRect::ExtendBy'
SmRect::operator = (SmRect(nWidth, nHeight));
}
diff --git a/starmath/source/parse.cxx b/starmath/source/parse.cxx
index 4703a973a968..a05f8a052405 100644
--- a/starmath/source/parse.cxx
+++ b/starmath/source/parse.cxx
@@ -1779,7 +1779,7 @@ void SmParser::Attribut()
SmNode *pAttr;
SmScaleMode eScaleMode = SCALE_NONE;
- // get appropriate node for the attribut itself
+ // get appropriate node for the attribute itself
switch (m_aCurToken.eType)
{ case TUNDERLINE :
case TOVERLINE :
diff --git a/svx/source/dialog/srchdlg.cxx b/svx/source/dialog/srchdlg.cxx
index 22f71bee30d3..eacce2d8f7fc 100644
--- a/svx/source/dialog/srchdlg.cxx
+++ b/svx/source/dialog/srchdlg.cxx
@@ -388,7 +388,7 @@ void SvxSearchDialog::Construct_Impl()
InitControls_Impl();
- // Get attribut sets only once in construtor()
+ // Get attribute sets only once in construtor()
const SfxPoolItem* ppArgs[] = { pSearchItem, 0 };
const SvxSetItem* pSrchSetItem =
(const SvxSetItem*) rBindings.GetDispatcher()->Execute( FID_SEARCH_SEARCHSET, SFX_CALLMODE_SLOT, ppArgs );
diff --git a/sw/inc/crsrsh.hxx b/sw/inc/crsrsh.hxx
index dd1bca59f910..b3386e7d7bbb 100644
--- a/sw/inc/crsrsh.hxx
+++ b/sw/inc/crsrsh.hxx
@@ -169,7 +169,7 @@ private:
Link m_aFlyMacroLnk; /**< Link will be called, if the Crsr is set
into a fly. A macro can be then becalled */
- Link m_aChgLnk; /**< link will be called by every attribut/
+ Link m_aChgLnk; /**< link will be called by every attribute/
format changes at cursor position.*/
Link m_aGrfArrivedLnk; ///< Link calls to UI if a graphic is arrived
diff --git a/sw/source/core/access/accportions.hxx b/sw/source/core/access/accportions.hxx
index 8ec578128279..94743cdeb27a 100644
--- a/sw/source/core/access/accportions.hxx
+++ b/sw/source/core/access/accportions.hxx
@@ -158,7 +158,7 @@ public:
void GetSentenceBoundary( com::sun::star::i18n::Boundary& rBound,
sal_Int32 nPos );
- // get (a) boundary for attribut change
+ // get (a) boundary for attribute change
void GetAttributeBoundary( com::sun::star::i18n::Boundary& rBound,
sal_Int32 nPos ) const;
diff --git a/sw/source/core/doc/docruby.cxx b/sw/source/core/doc/docruby.cxx
index 3c7490427a19..4fe2990869f2 100644
--- a/sw/source/core/doc/docruby.cxx
+++ b/sw/source/core/doc/docruby.cxx
@@ -42,7 +42,7 @@ using namespace ::com::sun::star::i18n;
/*
* Members in the list:
* - String - the orig text
- * - SwFmtRuby - the ruby attribut
+ * - SwFmtRuby - the ruby attribute
*/
sal_uInt16 SwDoc::FillRubyList( const SwPaM& rPam, SwRubyList& rList,
sal_uInt16 nMode )
@@ -123,7 +123,7 @@ sal_uInt16 SwDoc::SetRubyList( const SwPaM& rPam, const SwRubyList& rList,
const SwRubyListEntry* pEntry = &rList[ nListEntry++ ];
if( aCheckEntry.GetRubyAttr() != pEntry->GetRubyAttr() )
{
- // set/reset the attribut
+ // set/reset the attribute
if( !pEntry->GetRubyAttr().GetText().isEmpty() )
{
InsertPoolItem( aPam, pEntry->GetRubyAttr(), 0 );
@@ -154,7 +154,7 @@ sal_uInt16 SwDoc::SetRubyList( const SwPaM& rPam, const SwRubyList& rList,
{
const SwRubyListEntry* pEntry = &rList[ nListEntry++ ];
- // set/reset the attribut
+ // set/reset the attribute
if( !pEntry->GetRubyAttr().GetText().isEmpty() &&
!pEntry->GetText().isEmpty() )
{
@@ -203,7 +203,7 @@ sal_Bool SwDoc::_SelectNextRubyChars( SwPaM& rPam, SwRubyListEntry& rEntry, sal_
}
// ----- search the start
- // --- look where a ruby attribut starts
+ // --- look where a ruby attribute starts
sal_uInt16 nHtIdx = USHRT_MAX;
const SwpHints* pHts = pTNd->GetpSwpHints();
const SwTxtAttr* pAttr = 0;
diff --git a/sw/source/core/layout/atrfrm.cxx b/sw/source/core/layout/atrfrm.cxx
index 5f9923b3895c..da13f6183025 100644
--- a/sw/source/core/layout/atrfrm.cxx
+++ b/sw/source/core/layout/atrfrm.cxx
@@ -257,7 +257,7 @@ bool SwFmtFrmSize::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
// #95848# returned size should never be zero.
// (there was a bug that allowed for setting height to 0.
// Thus there some documents existing with that not allowed
- // attribut value which may cause problems on import.)
+ // attribute value which may cause problems on import.)
rVal <<= (sal_Int32)convertTwipToMm100(m_aSize.Height() < MINLAY ? MINLAY : m_aSize.Height() );
break;
case MID_FRMSIZE_SIZE_TYPE:
diff --git a/sw/source/core/layout/colfrm.cxx b/sw/source/core/layout/colfrm.cxx
index a6317ce4bf99..a6405298629d 100644
--- a/sw/source/core/layout/colfrm.cxx
+++ b/sw/source/core/layout/colfrm.cxx
@@ -162,7 +162,7 @@ static sal_Bool lcl_AddColumns( SwLayoutFrm *pCont, sal_uInt16 nCount )
/** add or remove columns from a layoutframe.
*
- * Normally, a layoutframe with a column attribut of 1 or 0 columns contains
+ * Normally, a layoutframe with a column attribute of 1 or 0 columns contains
* no columnframe. However, a sectionframe with "footnotes at the end" needs
* a columnframe.
*
diff --git a/sw/source/core/layout/ftnfrm.cxx b/sw/source/core/layout/ftnfrm.cxx
index 098d738b2a75..c957bb45d209 100644
--- a/sw/source/core/layout/ftnfrm.cxx
+++ b/sw/source/core/layout/ftnfrm.cxx
@@ -1600,7 +1600,7 @@ void SwFtnBossFrm::AppendFtn( SwCntntFrm *pRef, SwTxtFtn *pAttr )
SwFtnFrm *SwFtnBossFrm::FindFtn( const SwCntntFrm *pRef, const SwTxtFtn *pAttr )
{
- // the easiest and savest way goes via the attribut
+ // the easiest and savest way goes via the attribute
OSL_ENSURE( pAttr->GetStartNode(), "FtnAtr without StartNode." );
SwNodeIndex aIdx( *pAttr->GetStartNode(), 1 );
SwCntntNode *pNd = aIdx.GetNode().GetCntntNode();
diff --git a/sw/source/core/text/itrcrsr.cxx b/sw/source/core/text/itrcrsr.cxx
index e68e20b6870e..957f86ead920 100644
--- a/sw/source/core/text/itrcrsr.cxx
+++ b/sw/source/core/text/itrcrsr.cxx
@@ -1319,7 +1319,7 @@ sal_Int32 SwTxtCursor::GetCrsrOfst( SwPosition *pPos, const Point &rPoint,
KSHORT nX = KSHORT( x );
- // If there are attribut changes in the line, search for the paragraph,
+ // If there are attribute changes in the line, search for the paragraph,
// in which nX is situated.
SwLinePortion *pPor = pCurr->GetFirstPortion();
sal_Int32 nCurrStart = nStart;
diff --git a/sw/source/core/text/pormulti.cxx b/sw/source/core/text/pormulti.cxx
index 9965493023a3..1ba90a9792f5 100644
--- a/sw/source/core/text/pormulti.cxx
+++ b/sw/source/core/text/pormulti.cxx
@@ -283,8 +283,8 @@ SwDoubleLinePortion::SwDoubleLinePortion(SwDoubleLinePortion& rDouble, sal_Int32
/*--------------------------------------------------
* SwDoubleLinePortion::SwDoubleLinePortion(..)
- * This constructor uses the textattribut to get the right brackets.
- * The textattribut could be a 2-line-attribute or a character- or
+ * This constructor uses the textattribute to get the right brackets.
+ * The textattribute could be a 2-line-attribute or a character- or
* internetstyle, which contains the 2-line-attribute.
* --------------------------------------------------*/
@@ -2271,7 +2271,7 @@ SwLinePortion* SwTxtFormatter::MakeRestPortion( const SwLineLayout* pLine,
if ( !pCreate )
{
- OSL_ENSURE( !pHelpMulti->GetLen(), "Multiportion without attribut?" );
+ OSL_ENSURE( !pHelpMulti->GetLen(), "Multiportion without attribute?" );
if ( nMultiPos )
--nMultiPos;
pCreate = GetInfo().GetMultiCreator( --nMultiPos, 0 );
diff --git a/sw/source/core/unocore/unoobj.cxx b/sw/source/core/unocore/unoobj.cxx
index 1eeddb71fef4..229b17ded4d1 100644
--- a/sw/source/core/unocore/unoobj.cxx
+++ b/sw/source/core/unocore/unoobj.cxx
@@ -2389,7 +2389,7 @@ void SAL_CALL SwXTextCursor::firePropertiesChangeEvent(
OSL_FAIL("SwXTextCursor::firePropertiesChangeEvent(): not implemented");
}
-// para specific attribut ranges
+// para specific attribute ranges
static sal_uInt16 g_ParaResetableSetRange[] = {
RES_FRMATR_BEGIN, RES_FRMATR_END-1,
RES_PARATR_BEGIN, RES_PARATR_END-1,
@@ -2398,7 +2398,7 @@ static sal_uInt16 g_ParaResetableSetRange[] = {
0
};
-// selection specific attribut ranges
+// selection specific attribute ranges
static sal_uInt16 g_ResetableSetRange[] = {
RES_CHRATR_BEGIN, RES_CHRATR_END-1,
RES_TXTATR_INETFMT, RES_TXTATR_INETFMT,
diff --git a/sw/source/filter/ww8/wrtw8nds.cxx b/sw/source/filter/ww8/wrtw8nds.cxx
index fafa595523b0..2fcf0f6d9d73 100644
--- a/sw/source/filter/ww8/wrtw8nds.cxx
+++ b/sw/source/filter/ww8/wrtw8nds.cxx
@@ -2687,7 +2687,7 @@ void MSWordExportBase::OutputSectionNode( const SwSectionNode& rSectionNode )
&& rSection.GetType() != TOX_CONTENT_SECTION && rSection.GetType() != TOX_HEADER_SECTION) //No sections in table
{
// if the first Node inside the section has an own
- // PageDesc or PageBreak attribut, then dont write
+ // PageDesc or PageBreak attribute, then dont write
// here the section break
sal_uLong nRstLnNum = 0;
const SfxItemSet* pSet;
diff --git a/sw/source/ui/index/swuiidxmrk.cxx b/sw/source/ui/index/swuiidxmrk.cxx
index 9760f546f66b..aecb9969dcac 100644
--- a/sw/source/ui/index/swuiidxmrk.cxx
+++ b/sw/source/ui/index/swuiidxmrk.cxx
@@ -872,7 +872,7 @@ void SwIndexMarkPane::UpdateDialog()
m_pKey2DCB->SetReadOnly( !bEnable );
pSh->SelectTxtAttr( RES_TXTATR_TOXMARK, pMark->GetTxtTOXMark() );
- // we need the point at the start of the attribut
+ // we need the point at the start of the attribute
pSh->SwapPam();
pSh->EndCrsrMove();
diff --git a/xmloff/source/forms/elementexport.hxx b/xmloff/source/forms/elementexport.hxx
index afde7f0db4c5..ed0a89a5fae6 100644
--- a/xmloff/source/forms/elementexport.hxx
+++ b/xmloff/source/forms/elementexport.hxx
@@ -227,7 +227,7 @@ namespace xmloff
*/
void exportCellListSourceRange( );
- /** exports the attribut(s) for the ImagePosition property
+ /** exports the attribute(s) for the ImagePosition property
*/
void exportImagePositionAttributes();
diff --git a/sw/inc/editsh.hxx b/sw/inc/editsh.hxx
index 5b56b09277b8..e87219c9b215 100644
--- a/sw/inc/editsh.hxx
+++ b/sw/inc/editsh.hxx
@@ -245,7 +245,7 @@ public:
* @see GetPaMParAttr()
*
* @param rSet
* output parameter - the SfxItemSet where the automatic paragraph format attribut(s) will be store.
* The attributes aren't invalidated or cleared if the function reach the getMaxLookup limite.
*
* @return true if the function inspect all the nodes point by the pPaM parameter,
@@ -930,7 +930,7 @@ public:
static SwAutoCompleteWord& GetAutoCompleteWords();
/** @return a scaling factor of selected text. Used for the rotated
- character attribut dialog. */
+ character attribute dialog. */
sal_uInt16 GetScalingOfSelectedText() const;
/// Ctor/Dtor.
@@ -245,7 +245,7 @@ public:
*
* @param rSet
- * output parameter - the SfxItemSet where the automatic paragraph format attribut(s) will be store.
+ * output parameter - the SfxItemSet where the automatic paragraph format attribute(s) will be store.
* The attributes aren't invalidated or cleared if the function reach the getMaxLookup limite.
*